import { ReplaySubject } from 'rxjs';
import { isElementRemoved } from './operators/until-view-destroyed';
/**
 * Auto-unsubscribe when the targeted element is removed from the DOM
 */
export function autoUnsubscribe(subscription, element) {
    if (typeof MutationObserver !== 'undefined') {
        const stop$ = new ReplaySubject();
        const hasBeenRemoved = isElementRemoved(element);
        setTimeout(() => {
            const domObserver = new MutationObserver((records) => {
                if (records.some(hasBeenRemoved)) {
                    subscription.unsubscribe();
                    domObserver.disconnect();
                }
            });
            domObserver.observe(element.parentNode, { childList: true });
        }, 20);
    }
}
//# sourceMappingURL=auto-unsubscribe.js.map